@@ -1,3 +1,3 @@
 from powerbot_backtesting.utils.constants import *
 from powerbot_backtesting.utils.helper_functions import _order_matching, _cache_data, _check_contracts, \
-    _get_file_cachepath, _find_cache, _orderbook_data_transformation, _historic_data_transformation
+    _get_file_cachepath, _find_cache, _orderbook_data_transformation, _historic_data_transformation, _get_private_data
